@@ -27,7 +27,7 @@ import string
 import tempfile
 import time
 import typing
-from typing import Callable, List, Optional, Tuple, Union  # noqa: H301
+from typing import Callable, List, Optional, Tuple, Union
 
 from castellan import key_manager
 from os_brick.remotefs import remotefs as remotefs_brick
@@ -37,7 +37,6 @@ from oslo_serialization import jsonutils
 from oslo_utils import imageutils
 from oslo_utils.secretutils import md5
 from oslo_utils import units
-import six
 
 from cinder import compute
 from cinder import context
@@ -890,8 +889,8 @@ class RemoteFSSnapDriverBase(RemoteFSDriver):
                           })
             else:
                 backing_file_template = \
-                    "(%(basedir)s/[0-9a-f]+/)?%" \
-                    "(volname)s(.(tmp-snap-)?[0-9a-f-]+)?%(valid_ext)s$" % {
+                    "(%(basedir)s/[0-9a-f]+/)?" \
+                    "%(volname)s(.(tmp-snap-)?[0-9a-f-]+)?%(valid_ext)s$" % {
                         'basedir': basedir,
                         'volname': volume_name,
                         'valid_ext': valid_ext,
@@ -1040,7 +1039,7 @@ class RemoteFSSnapDriverBase(RemoteFSDriver):
 
         Returns string in a hex format.
         """
-        if isinstance(base_str, six.text_type):
+        if isinstance(base_str, str):
             base_str = base_str.encode('utf-8')
         return md5(base_str, usedforsecurity=False).hexdigest()
 
@@ -1721,9 +1720,18 @@ class RemoteFSSnapDriverBase(RemoteFSDriver):
             self._create_snapshot_online(snapshot,
                                          backing_filename,
                                          new_snap_path)
+            # Update the format for the volume and the connection_info. The
+            # connection_info needs to reflect the current volume format in
+            # order for Nova to create the disk device correctly whenever the
+            # instance is stopped/started or rebooted.
+            new_format = 'qcow2'
+            snapshot.volume.admin_metadata['format'] = new_format
+            with snapshot.volume.obj_as_admin():
+                snapshot.volume.save()
             # Update reference in the only attachment (no multi-attach support)
             attachment = snapshot.volume.volume_attachment[0]
             attachment.connection_info['name'] = active
+            attachment.connection_info['format'] = new_format
             # Let OVO know it has been updated
             attachment.connection_info = attachment.connection_info
             attachment.save()
